@@ -3,17 +3,22 @@ from zope.interface import Interface
 from Products.Archetypes.interfaces import IReferenceable
 
 from Products.membrane.interfaces import IMembraneTool
+from Products.membrane.interfaces import user as user_ifaces
 from Products.membrane.at import interfaces as at_ifaces
 
 # name of IMembraneUserChangerAvail interface has been changed
 try:
-    from Products.membrane.interfaces.user import IMembraneUserChangerAvail \
-        as IMembraneUserChanger
-    IMembraneUserChanger  # pyflakes
+    from Products.membrane.interfaces.user import IMembraneUserChangerAvail as IMembraneUserChanger
 except:
     from Products.membrane.interfaces.user import IMembraneUserChanger
+from Products.membrane.at import interfaces as at_ifaces
 
 
+class IRememberLayer(Interface):
+    """Products.remember browser layer marker.
+
+    Installed via browserlayer.xml."""
+
 class IReMember(Interface):
     """
     A marker interface that declares the provider to be a Remember
@@ -65,9 +70,7 @@ class IRememberMembraneTool(IMembraneTool):
     membrane tool at setup time
     """
 
-
-class IRememberUserChanger(IReferenceable,
-                           IMembraneUserChanger):
+class IRememberUserChanger(at_ifaces.IUserChanger):
     """
     IRemember user changer uses the _setPassword method
     This is the mutator function for the member object
